==> delegate6.1.18.tar.gz: delegate6.1.18/src/param.h <==
/*////////////////////////////////////////////////////////////////////////
Copyright (c) 1995 Electrotechnical Laboratry (ETL), AIST, MITI

Permission to use, copy, modify, and distribute this material for any
purpose and without fee is hereby granted, provided that the above
copyright notice and this permission notice appear in all copies, and
that the name of ETL not be used in advertising or publicity pertaining
to this material without the specific, prior written permission of an
authorized representative of ETL.
ETL MAKES NO REPRESENTATIONS ABOUT THE ACCURACY OR SUITABILITY OF THIS
MATERIAL FOR ANY PURPOSE.  IT IS PROVIDED "AS IS", WITHOUT ANY EXPRESS
OR IMPLIED WARRANTIES.
/////////////////////////////////////////////////////////////////////////
Content-Type:	program/C; charset=US-ASCII
Program:	param.h
Author:		Yutaka Sato <ysato@etl.go.jp>
Description:
History:
	950205	created
//////////////////////////////////////////////////////////////////////#*/

extern char *DELEGATE_getEnv();

extern char P_ABORTLOG[];
extern char P_ACTDIR[];
extern char P_ADMDIR[];
extern char P_ADMIN[];
extern char P_ADMINPASS[];
extern char P_AUTH[];
extern char P_AUTHORIZER[];
extern char P_BASEURL[];
extern char P_CACHE[];
extern char P_CACHEDIR[];
extern char P_CACHEFILE[];
extern char P_CGIENV[];
extern char P_CHARCODE[];
extern char P_CHARSET[];
extern char P_CHROOT[];
extern char P_CMAP[];
extern char P_CONNECT[];
extern char P_COUNTER[];
extern char P_CRON[];
extern char P_CRONS[];
extern char P_DBFILE[];
extern char P_DGOPTS[];
extern char P_DGPATH[];
extern char P_DGROOT[];
extern char P_DELAY[];
extern char P_DELEGATE[];
extern char P_DNSCONF[];
extern char P_ERRORLOG[];
extern char P_ETCDIR[];
extern char P_EXPIRE[];
extern char P_EXPIRELOG[];
extern char P_FCL[];
extern char P_FMD[];
extern char P_FSV[];
extern char P_FFROMCL[];
extern char P_FFROMMD[];
extern char P_FFROMSV[];
extern char P_FILETYPE[];
extern char P_FTOCL[];
extern char P_FTOMD[];
extern char P_FTOSV[];
extern char P_FTPCONF[];
extern char P_FORCEON[];
extern char P_FUNC[];
extern char P_HOSTS[];
extern char P_HTMLCONV[];
extern char P_HTTPMAIL[];
extern char P_HTTPCONF[];
extern char P_ICP[];
extern char P_ICPCONF[];
extern char P_INETD[];
extern char P_INPARAM[];
extern char P_LIBDIR[];
extern char P_LIBPATH[];
extern char P_LOG[];
extern char P_LOGDIR[];
extern char P_LOGFILE[];
extern char P_LOGCENTER[];
extern char P_MAILSPOOL[];
extern char P_MANAGER[];
extern char P_MASTER[];
extern char P_MASTERP[];
extern char P_MAXIMA[];
extern char P_MIMECONV[];
extern char P_MOUNT[];
extern char P_NNTPCONF[];
extern char P_OWNER[];
extern char P_OVERRIDE[];
extern char P_PERMIT[];
extern char P_PGP[];
extern char P_PIDFILE[];
extern char P_PORT[];
extern char P_PROTOLOG[];
extern char P_PROXY[];
extern char P_PUBLIC[];
extern char P_QPORT[];
extern char P_RIDENT[];
extern char P_RPORT[];
extern char P_REACHABLE[];
extern char P_RES_CONF[];
extern char P_RES_DEBUG[];
extern char P_RES_LOG[];
extern char P_RES_NS[];
extern char P_RES_RR[];
extern char P_RES_VRFY[];
extern char P_RESOLV[];
extern char P_RELIABLE[];
extern char P_REMITTABLE[];
extern char P_RELAY[];
extern char P_ROUTE[];
extern char P_SERVER[];
extern char P_SHARE[];
extern char P_SMTPCONF[];
extern char P_SMTPGATE[];
extern char P_SMTPSERVER[];
extern char P_SOCKS[];
extern char P_SSLTUNNEL[];
extern char P_SYSLOG[];
extern char P_INVITE[];
extern char P_THRUWAY_ENTR[];
extern char P_THRUWAY_EXIT[];
extern char P_TMPDIR[];
extern char P_TUNNEL[];
extern char P_TIMEOUT[];
extern char P_TRACELOG[];
extern char P_UMASK[];
extern char P_URICONV[];
extern char P_VARDIR[];
extern char P_VSAP[];
extern char P_WORKDIR[];
extern char P_XCOM[];
extern char P_XFIL[];

extern char P_EXEC_PATH[];
extern char P_EXEC_ENV[];
extern char P_START_TIME[];
extern char P_ALIVE_PEERS[];
extern char P_MASTERPMARK[];
extern char P_INPUT[];

extern int scan_CMAP();
extern int scan_HOSTS();
extern int scan_MASTER();
extern int scan_PROXY();
extern int scan_MOUNT();
extern int scan_PERMIT();
extern int scan_REMITTABLE();
extern int scan_RELIABLE();
extern int scan_REACHABLE();
extern int scan_ROUTE();
extern int scan_CONNECT();
extern int scan_LOG();
extern int scan_AUTH();
extern int scan_AUTHORIZER();
extern int scan_INVITE();
extern int scan_FILETYPE();
extern int scan_OWNER();
extern int scan_CHARCODE();
extern int scan_CHARSET();
extern int scan_HTTPCONF();
extern int scan_NNTPCONF();
extern int scan_EXPIRE();
extern int scan_RELAY();
extern int scan_TIMEOUT();
extern int scan_DELAY();
extern int scan_PGP();
extern int scan_MAXIMA();
extern int scan_PORT();
extern int scan_VSAP();
extern int scan_CRON();
extern int scan_CRONS();
extern int scan_SMTPCONF();
extern int scan_SMTPGATE();
extern int scan_INETD();
extern int scan_ICP();
extern int scan_ICPCONF();
extern int scan_DNSCONF();
extern int scan_HTMLCONV();
extern int scan_URICONV();
extern int scan_SHARE();
extern int scan_SOCKS();

#define INC_SYM		"+="
#define INC_SYM_LEN	(sizeof(INC_SYM)-1)

==> delegate9.0.0.tar.gz: delegate9.0.0/src/param.h <==
/*////////////////////////////////////////////////////////////////////////
Copyright (c) 1995 Electrotechnical Laboratry (ETL), AIST, MITI

Permission to use, copy, modify, and distribute this material for any
purpose and without fee is hereby granted, provided that the above
copyright notice and this permission notice appear in all copies, and
that the name of ETL not be used in advertising or publicity pertaining
to this material without the specific, prior written permission of an
authorized representative of ETL.
ETL MAKES NO REPRESENTATIONS ABOUT THE ACCURACY OR SUITABILITY OF THIS
MATERIAL FOR ANY PURPOSE.  IT IS PROVIDED "AS IS", WITHOUT ANY EXPRESS
OR IMPLIED WARRANTIES.
/////////////////////////////////////////////////////////////////////////
Content-Type:	program/C; charset=US-ASCII
Program:	param.h
Author:		Yutaka Sato <ysato@etl.go.jp>
Description:
History:
	950205	created
//////////////////////////////////////////////////////////////////////#*/

#include "ystring.h"
const char *DELEGATE_getEnv(PCStr(env));

extern char P_ABORTLOG[];
extern char P_ACTDIR[];
extern char P_ADMDIR[];
extern char P_ADMIN[];
extern char P_ADMINPASS[];
extern char P_AUTH[];
extern char P_AUTHORIZER[];
extern char P_BASEURL[];
extern char P_CACHE[];
extern char P_CACHEDIR[];
extern char P_CACHEFILE[];
extern char P_CFI[];
extern char P_CGIENV[];
extern char P_CHARCODE[];
extern char P_CHARSET[];
extern char P_CHROOT[];
extern char P_CMAP[];
extern char P_CONNECT[];
extern char P_COUNTER[];
extern char P_CRON[];
extern char P_CRONS[];
extern char P_CRYPT[];
extern char P_DATAPATH[];
extern char P_DBFILE[];
extern char P_DGOPTS[];
extern char P_DGPATH[];
extern char P_DGROOT[];
extern char P_DELAY[];
extern char P_DELEGATE[];
extern char P_DEST[];
extern char P_DNSCONF[];
extern char P_ERRORLOG[];
extern char P_ETCDIR[];
extern char P_EXPIRE[];
extern char P_EXPIRELOG[];
extern char P_FCL[];
extern char P_FMD[];
extern char P_FSV[];
extern char P_FFROMCL[];
extern char P_FFROMMD[];
extern char P_FFROMSV[];
extern char P_FILETYPE[];
extern char P_FORWARD[];
extern char P_FTOCL[];
extern char P_FTOMD[];
extern char P_FTOSV[];
extern char P_FTPCONF[];
extern char P_FTPTUNNEL[];
extern char P_FUNC[];
extern char P_HOSTS[];
extern char P_HOSTLIST[];
extern char P_HTMLCONV[];
extern char P_HTTPCONF[];
extern char P_ICP[];
extern char P_ICPCONF[];
extern char P_INETD[];
extern char P_IPV6[];
extern char P_INPARAM[];
extern char P_LIBDIR[];
extern char P_LIBPATH[];
extern char P_LOG[];
extern char P_LOGDIR[];
extern char P_LOGFILE[];
extern char P_LOGCENTER[];
extern char P_MAILSPOOL[];
extern char P_MANAGER[];
extern char P_MASTER[];
extern char P_MASTERP[];
extern char P_MAXIMA[];
extern char P_MIMECONV[];
extern char P_MOUNT[];
extern char P_MYAUTH[];
extern char P_NNTPCONF[];
extern char P_OWNER[];
extern char P_OVERRIDE[];
extern char P_PERMIT[];
extern char P_PAMCONF[];
extern char P_PGP[];
extern char P_PIDFILE[];
extern char P_PORT[];
extern char P_PROTOLOG[];
extern char P_PROXY[];
extern char P_QPORT[];
extern char P_RIDENT[];
extern char P_RPORT[];
extern char P_REACHABLE[];
extern char P_REJECT[];
extern char P_RES_AF[];
extern char P_RES_CONF[];
extern char P_RES_DEBUG[];
extern char P_RES_LOG[];
extern char P_RES_NS[];
extern char P_RES_RR[];
extern char P_RES_VRFY[];
extern char P_RESOLV[];
extern char P_RELIABLE[];
extern char P_REMITTABLE[];
extern char P_RELAY[];
extern char P_ROUTE[];
extern char P_SERVCONF[];
extern char P_SERVER[];
extern char P_SERVICE[];
extern char P_SHARE[];
extern char P_SMTPCONF[];
extern char P_SMTPGATE[];
extern char P_SMTPSERVER[];
extern char P_SOCKOPT[];
extern char P_SOCKS[];
extern char P_SOXCONF[];
extern char P_SRCIF[];
extern char P_SSLTUNNEL[];
extern char P_STLS[];
extern char P_SYSLOG[];
extern char P_INVITE[];
extern char P_TELNETCONF[];
extern char P_THRUWAY_ENTR[];
extern char P_THRUWAY_EXIT[];
extern char P_TMPDIR[];
extern char P_TUNNEL[];
extern char P_TIMEOUT[];
extern char P_TRACELOG[];
extern char P_UMASK[];
extern char P_URICONV[];
extern char P_VARDIR[];
extern char P_VSAP[];
extern char P_WORKDIR[];
extern char P_XCOM[];
extern char P_XFIL[];

extern char P_EXEC_PATH[];
extern char P_EXEC_ENV[];
extern char P_START_TIME[];
extern char P_ALIVE_PEERS[];
extern char P_MASTERPMARK[];
extern char P_INPUT[];

typedef struct DGCtx *DGCp;
typedef void scanPFunc(DGCp Conn,PCStr(param));
typedef int iscanPFunc(DGCp Conn,PCStr(param));
typedef void (*scanPFUNCP)(DGCp Conn,PCStr(param));
int DELEGATE_scanEnv(DGCp Conn,PCStr(name),scanPFUNCP func,...);

int scan_HTMLCONV(void*,PCStr(conv));
int scan_URICONV(void*,PCStr(conv));
void scan_PGP(void*,PCStr(conf));

scanPFunc scan_CMAP;
scanPFunc scan_HOSTS;
scanPFunc scan_MASTER;
scanPFunc scan_PROXY;
scanPFunc scan_MOUNT;
scanPFunc scan_PERMIT;
scanPFunc scan_REMITTABLE;
scanPFunc scan_RELIABLE;
scanPFunc scan_REACHABLE;
scanPFunc scan_REJECT;
scanPFunc scan_ROUTE;
scanPFunc scan_CONNECT;
scanPFunc scan_LOG;
scanPFunc scan_AUTH;
scanPFunc scan_AUTHORIZER;
scanPFunc scan_INVITE;
iscanPFunc scan_FILETYPE;
iscanPFunc scan_OWNER;
scanPFunc scan_CHARCODE;
scanPFunc scan_CHARSET;
scanPFunc scan_HTTPCONF;
scanPFunc scan_NNTPCONF;
scanPFunc scan_EXPIRE;
scanPFunc scan_RELAY;
scanPFunc scan_TIMEOUT;
scanPFunc scan_DELAY;
scanPFunc scan_PAMCONF;
scanPFunc scan_MAXIMA;
scanPFunc scan_PORT;
scanPFunc scan_VSAP;
scanPFunc scan_CRON;
scanPFunc scan_CRONS;
scanPFunc scan_SMTPCONF;
iscanPFunc scan_SMTPGATE;
scanPFunc scan_INETD;
scanPFunc scan_IPV6;
scanPFunc scan_ICP;
scanPFunc scan_ICPCONF;
scanPFunc scan_DNSCONF;
scanPFunc scan_SHARE;
scanPFunc scan_SOCKOPT;
scanPFunc scan_SOCKS;
scanPFunc scan_SOXCONF;
scanPFunc scan_TELNETCONF;
scanPFunc scan_FTPCONF;
scanPFunc scan_SRCIF;
scanPFunc scan_MYAUTH;
scanPFunc scan_FORWARD;
scanPFunc scan_HOSTLIST;
iscanPFunc scan_FTPTUNNEL;
scanPFunc scan_SERVICE;
scanPFunc scan_RIDENT;
scanPFunc scan_LOGFILE;
scanPFunc scan_FCL;
scanPFunc scan_FTOCL;
scanPFunc scan_FFROMCL;
scanPFunc scan_FSV;
scanPFunc scan_FTOSV;
scanPFunc scan_FFROMSV;
scanPFunc scan_BASEURL;
scanPFunc scan_DELEGATE;
scanPFunc scan_STLS;

#define INC_SYM		"+="
#define INC_SYM_LEN	(sizeof(INC_SYM)-1)
